@@ -2,7 +2,7 @@ use std::slice::Iter;
 use std::sync::Arc;
 use vrp_core::construction::constraints::*;
 use vrp_core::construction::heuristics::{ActivityContext, RouteContext, SolutionContext};
-use vrp_core::models::problem::{Job, TransportCost};
+use vrp_core::models::problem::{Job, TransportCost, TravelTime};
 
 pub struct ReachableModule {
     constraints: Vec<ConstraintVariant>,
@@ -57,18 +57,24 @@ impl HardActivityConstraint for ReachableHardActivityConstraint {
         let target = activity_ctx.target;
         let next = activity_ctx.next;
 
-        let profile = &route_ctx.route.actor.vehicle.profile;
-
-        let prev_to_target =
-            self.transport.distance(profile, prev.place.location, target.place.location, prev.schedule.departure);
+        let prev_to_target = self.transport.distance(
+            &route_ctx.route,
+            prev.place.location,
+            target.place.location,
+            TravelTime::Departure(prev.schedule.departure),
+        );
 
         if prev_to_target < 0. {
             return Some(ActivityConstraintViolation { code: self.code, stopped: false });
         }
 
         if let Some(next) = next {
-            let target_to_next =
-                self.transport.distance(profile, target.place.location, next.place.location, target.schedule.departure);
+            let target_to_next = self.transport.distance(
+                &route_ctx.route,
+                target.place.location,
+                next.place.location,
+                TravelTime::Departure(target.schedule.departure),
+            );
             if target_to_next < 0. {
                 return Some(ActivityConstraintViolation { code: self.code, stopped: false });
             }
