@@ -11,6 +11,7 @@ use crate::{format_time, parse_time};
 use std::cmp::Ordering;
 use std::io::{BufWriter, Write};
 use vrp_core::construction::constraints::route_intervals;
+use vrp_core::construction::heuristics::UnassignedCode;
 use vrp_core::models::common::*;
 use vrp_core::models::problem::{Multi, TravelTime};
 use vrp_core::models::solution::{Activity, Route};
@@ -505,16 +506,40 @@ fn calculate_load(current: MultiDimLoad, act: &Activity, is_multi_dimen: bool) -
 }
 
 fn create_unassigned(solution: &Solution) -> Option<Vec<UnassignedJob>> {
+    let create_simple_reasons = |code: i32| {
+        let (code, reason) = map_code_reason(code);
+        vec![UnassignedJobReason { code: code.to_string(), description: reason.to_string(), detail: None }]
+    };
+
     let unassigned = solution
         .unassigned
         .iter()
         .filter(|(job, _)| job.dimens().get_value::<String>("vehicle_id").is_none())
         .map(|(job, code)| {
-            let (code, reason) = map_code_reason(*code);
-            UnassignedJob {
-                job_id: job.dimens().get_id().expect("job id expected").clone(),
-                reasons: vec![UnassignedJobReason { code: code.to_string(), description: reason.to_string() }],
-            }
+            let job_id = job.dimens().get_id().expect("job id expected").clone();
+
+            let reasons = match code {
+                UnassignedCode::Simple(code) => create_simple_reasons(*code),
+                UnassignedCode::Detailed(details) if !details.is_empty() => details
+                    .iter()
+                    .map(|(actor, code)| {
+                        let (code, reason) = map_code_reason(*code);
+                        let dimens = &actor.vehicle.dimens;
+
+                        UnassignedJobReason {
+                            detail: Some(UnassignedJobDetail {
+                                vehicle_id: dimens.get_id().cloned().unwrap(),
+                                shift_index: dimens.get_value::<usize>("shift_index").cloned().unwrap(),
+                            }),
+                            code: code.to_string(),
+                            description: reason.to_string(),
+                        }
+                    })
+                    .collect(),
+                _ => create_simple_reasons(0),
+            };
+
+            UnassignedJob { job_id, reasons }
         })
         .collect::<Vec<_>>();
 
