@@ -5,7 +5,7 @@ use crate::helpers::*;
 #[test]
 fn can_use_vehicle_with_open_end() {
     let problem = Problem {
-        plan: Plan { jobs: vec![create_delivery_job("job1", vec![1., 0.])], ..create_empty_plan() },
+        plan: Plan { jobs: vec![create_delivery_job("job1", (1., 0.))], ..create_empty_plan() },
         fleet: Fleet {
             vehicles: vec![VehicleType {
                 shifts: vec![create_default_open_vehicle_shift()],
