@@ -28,7 +28,8 @@ fn can_use_vehicle_with_open_end() {
                 job_id: "job1".to_string(),
                 reasons: vec![UnassignedJobReason {
                     code: "REACHABLE_CONSTRAINT".to_string(),
-                    description: "location unreachable".to_string()
+                    description: "location unreachable".to_string(),
+                    detail: None,
                 }]
             }]),
             ..create_empty_solution()
