@@ -1,4 +1,4 @@
-mod area_allowance;
+mod area;
 mod max_distance;
 mod shift_time;
 mod tour_size;
