@@ -89,7 +89,7 @@ fn can_use_only_pickups_as_static_demand() {
                     end: Some(ShiftEnd {
                         earliest: None,
                         latest: format_time(1000.).to_string(),
-                        location: vec![10., 0.].to_loc(),
+                        location: (10., 0.).to_loc(),
                     }),
                     ..create_default_vehicle_shift()
                 }],
