@@ -32,7 +32,8 @@ fn can_unassign_multi_job_due_to_capacity() {
                 job_id: "multi".to_string(),
                 reasons: vec![UnassignedJobReason {
                     code: "CAPACITY_CONSTRAINT".to_string(),
-                    description: "does not fit into any vehicle due to capacity".to_string()
+                    description: "does not fit into any vehicle due to capacity".to_string(),
+                    detail: None,
                 }]
             }]),
             ..create_empty_solution()
