@@ -7,11 +7,11 @@ fn can_use_sequence_relation_with_strict_time_windows() {
     let problem = Problem {
         plan: Plan {
             jobs: vec![
-                create_delivery_job_with_times("job1", vec![10., 0.], vec![(150, 170)], 10.),
-                create_delivery_job_with_times("job2", vec![20., 0.], vec![(20, 30)], 10.),
-                create_delivery_job_with_times("job3", vec![30., 0.], vec![(40, 50)], 10.),
-                create_delivery_job_with_times("job4", vec![40., 0.], vec![(60, 150)], 10.),
-                create_delivery_job_with_times("job5", vec![50., 0.], vec![(70, 80)], 10.),
+                create_delivery_job_with_times("job1", (10., 0.), vec![(150, 170)], 10.),
+                create_delivery_job_with_times("job2", (20., 0.), vec![(20, 30)], 10.),
+                create_delivery_job_with_times("job3", (30., 0.), vec![(40, 50)], 10.),
+                create_delivery_job_with_times("job4", (40., 0.), vec![(60, 150)], 10.),
+                create_delivery_job_with_times("job5", (50., 0.), vec![(70, 80)], 10.),
             ],
             relations: Some(vec![Relation {
                 type_field: RelationType::Sequence,
