@@ -32,7 +32,8 @@ fn can_have_unassigned_due_to_missing_vehicle_skill() {
                 job_id: "job1".to_string(),
                 reasons: vec![UnassignedJobReason {
                     code: "SKILL_CONSTRAINT".to_string(),
-                    description: "cannot serve required skill".to_string()
+                    description: "cannot serve required skill".to_string(),
+                    detail: None
                 }]
             }]),
             ..create_empty_solution()
