@@ -7,12 +7,12 @@ fn can_balance_max_load() {
     let problem = Problem {
         plan: Plan {
             jobs: vec![
-                create_delivery_job("job1", vec![1., 0.]),
-                create_delivery_job("job2", vec![2., 0.]),
-                create_delivery_job("job3", vec![3., 0.]),
-                create_delivery_job("job4", vec![4., 0.]),
-                create_delivery_job("job5", vec![5., 0.]),
-                create_delivery_job("job6", vec![6., 0.]),
+                create_delivery_job("job1", (1., 0.)),
+                create_delivery_job("job2", (2., 0.)),
+                create_delivery_job("job3", (3., 0.)),
+                create_delivery_job("job4", (4., 0.)),
+                create_delivery_job("job5", (5., 0.)),
+                create_delivery_job("job6", (6., 0.)),
             ],
             ..create_empty_plan()
         },
