@@ -8,8 +8,8 @@ use vrp_core::models::Problem as CoreProblem;
 use vrp_core::models::Solution as CoreSolution;
 use vrp_core::rosomaxa::evolution::TelemetryMode;
 use vrp_core::solver::search::{Recreate, RecreateWithCheapest};
-use vrp_core::solver::RefinementContext;
 use vrp_core::solver::{create_default_config_builder, create_elitism_population, Solver};
+use vrp_core::solver::{get_default_telemetry_mode, RefinementContext};
 use vrp_core::utils::Environment;
 
 /// Runs solver with cheapest insertion heuristic.
@@ -53,7 +53,8 @@ pub fn solve_with_metaheuristic_and_iterations_without_check(
 pub fn solve(problem: Problem, matrices: Option<Vec<Matrix>>, generations: usize, perform_check: bool) -> Solution {
     get_core_solution(problem, matrices, perform_check, |problem: Arc<CoreProblem>| {
         let environment = Arc::new(Environment::default());
-        let (solution, _, _) = create_default_config_builder(problem.clone(), environment)
+        let telemetry_mode = get_default_telemetry_mode(environment.logger.clone());
+        let (solution, _, _) = create_default_config_builder(problem.clone(), environment, telemetry_mode)
             .with_max_generations(Some(generations))
             .build()
             .map(|config| Solver::new(problem, config))
