@@ -36,7 +36,7 @@ can_remove_orphan_break! {
 }
 
 fn can_remove_orphan_break_impl(break_job_loc: Option<Location>, break_activity_loc: Location, break_removed: bool) {
-    let (transport, _) = get_costs();
+    let (transport, activity) = get_costs();
     let fleet = test_fleet();
     let mut solution_ctx = SolutionContext {
         routes: vec![RouteContext::new_with_state(
@@ -55,7 +55,7 @@ fn can_remove_orphan_break_impl(break_job_loc: Option<Location>, break_activity_
     };
 
     ConstraintPipeline::default()
-        .add_module(Arc::new(BreakModule::new(transport, 0)))
+        .add_module(Arc::new(BreakModule::new(activity, transport, 0)))
         .accept_solution_state(&mut solution_ctx);
 
     if break_removed {
@@ -86,8 +86,8 @@ can_skip_merge_breaks! {
 }
 
 fn can_skip_merge_breaks_impl(source: Job, candidate: Job, expected: Result<(), i32>) {
-    let (transport, _) = get_costs();
-    let constraint = BreakModule::new(transport, 0);
+    let (transport, activity) = get_costs();
+    let constraint = BreakModule::new(activity, transport, 0);
 
     let result = constraint.merge(source, candidate).map(|_| ());
 
